#!/bin/sh

# LOLA - LOgos Look Amazing!
# Copyright 2008 BaderLab

# This script runs LOLA from a Linux shell

java -Xmx512M -jar lola-1.3-beta.jar 
